<!-- {{{1 -->

    File        : README.md
    Maintainer  : Felix C. Stegerman <flx@obfusk.net>
    Date        : 2020-06-20

    Copyright   : Copyright (C) 2020  Felix C. Stegerman
    Version     : v0.1.1
    License     : GPLv3+

<!-- }}}1 -->

[![GPLv3+](https://img.shields.io/badge/license-GPLv3+-blue.svg)](https://www.gnu.org/licenses/gpl-3.0.html)

## Description

proudcat - cat + :rainbow:

proudcat is basically a variant of
[`pridecat`](https://github.com/lunasorcery/pridecat)
written in python.

![screenshot](screenshot.png)

## Help

```bash
$ proudcat --help
```

## Requirements

Python >= 3.5 + click.

## Installing

### Using pip

```bash
$ pip install proudcat
```

### Manually

Install the dependencies (as e.g. debian packages or using `pip`):

```bash
$ apt install python3-click       # debian/ubuntu
$ pip install click               # pip
```

Then just put `proudcat` somewhere on your `$PATH` (e.g. `~/bin`).

## License

[![GPLv3+](https://www.gnu.org/graphics/gplv3-127x51.png)](https://www.gnu.org/licenses/gpl-3.0.html)

<!-- vim: set tw=70 sw=2 sts=2 et fdm=marker : -->
